#!/bin/bash
#
##

HACKNAME="touchblock"

# Pull libOTAUtils for logging & progress handling
[ -f ./libotautils5 ] && source ./libotautils5

HACKVER="1.2"

CONFIG_FILE="/etc/deviceConfig.conf"
CONFIG_FILE_BACKUP="/etc/deviceConfig.conf.bak"
CONFIG_FILE_MD5_1="839247de4cdb6bfac0989863db877d8e"    # FW 5.10.2 - 5.11.2
CONFIG_FILE_MD5_2="eb4136571b51bd7203eab2e0966bfb00"    # FW 5.12.1 - 5.13.5
CONFIG_FILE_MD5_3="ecc8818ba367fd199a227d386b8f70f3"    # FW 5.13.6 - ??

UPSTART_FILE="/etc/upstart/xbath.conf"

# Result codes
OK=0
ERR=1

otautils_update_progressbar

# Check if backup file exists and does meet our md5 expectations:
if [ -f $CONFIG_FILE_BACKUP ]; then
    logmsg "I" "install" "" "$CONFIG_FILE_BACKUP found"
    case "$(md5sum $CONFIG_FILE_BACKUP | head -c32)" in
        $CONFIG_FILE_MD5_1 | $CONFIG_FILE_MD5_2 | $CONFIG_FILE_MD5_3)
            logmsg "I" "install" "" "$CONFIG_FILE_BACKUP md5 correct"
            ;;
        *)
            logmsg "C" "install" "" "md5sum mismatch, bailing out: $(md5sum $CONFIG_FILE_BACKUP | head -c32)"
            ;;
    esac
else
    logmsg "C" "install" "" "$CONFIG_FILE_BACKUP not found"
    return ${ERR}
fi

otautils_update_progressbar

# Mount root rw
if ! mntroot rw; then
    logmsg "C" "install" "code=$?" "Unable to mount root rw"
    return ${ERR}
fi

otautils_update_progressbar

# Restore original config file
if ! mv $CONFIG_FILE_BACKUP $CONFIG_FILE; then
    logmsg "C" "install" "code=$?" "Unable to restore original config file"
    return ${ERR}
fi

otautils_update_progressbar

# Remove the upstart file
if ! rm $UPSTART_FILE; then
    logmsg "W" "install" "code=$?" "Unable to remove upstart file"
fi

otautils_update_progressbar

# Mount root ro
if ! mntroot ro; then
    logmsg "W" "install" "code=$?" "Unable to mount root ro"
fi

otautils_update_progressbar

return ${OK}